from HowdenLLM.providers.base_provider import BaseProvider
from dotenv import load_dotenv
import os
from huggingface_hub import InferenceClient
from .known_providers import KnownProviders


class HuggingFaceProvider(BaseProvider):
    provider = KnownProviders.HuggingFace

    def __init__(self,client: InferenceClient):
        self.client = client

    def complete(self, system: str, prompt: str, model: str, use_web_search_tool: bool) -> str:
        full_prompt = f"[System]: {system}\n[User]: {prompt}\n"
        response = self.client.text_generation(
            model=model,
            prompt=full_prompt,
            max_new_tokens=500,
            temperature=0.0,
        )
        return response


from abc import ABC
from HowdenLLM.providers.base_provider import BaseProvider
from anthropic import Anthropic
from .known_providers import KnownProviders

class AnthropicProvider(BaseProvider, ABC):
    provider = KnownProviders.Anthropic

    def __init__(self,client: Anthropic):
        self.client = client

    def complete(self, system: str, prompt: str, model: str, use_web_search_tool: bool) -> str:
        if model in ["claude-opus-4-6","claude-sonnet-4-6"]:
            message = self.client.messages.create(
                model=model,
                system=system,
                messages=[
                    {"role": "user","content": prompt}
                ],
                max_tokens=16000,
                temperature=0.0

            )
        else:
            raise Exception(f"Unsupported model: {model}")

        return message.content[0].text



from abc import ABC
from HowdenLLM.providers.base_provider import BaseProvider
from openai import OpenAI
from .known_providers import KnownProviders

class OpenAIProvider(BaseProvider, ABC):
    provider = KnownProviders.OpenAI

    def __init__(self,client: OpenAI):
        self.client = client

    def complete(self, system: str, prompt: str, model: str, use_web_search_tool: bool) -> str:

        if use_web_search_tool:
            tools = [
                { "type": "web_search" }
            ]
        else:
            tools = None

        if model in ["gpt-5", "gpt-5-mini", "gpt-5-nano"]:
            response = self.client.responses.create(
                model=model,
                input=[
                    {"role": "system", "content": system},
                    {"role": "user", "content": prompt}
                ],
                tools=tools,
                max_output_tokens=16000
            )
        else:
            raise Exception(f"Unsupported model: {model}")

        return response.output_text
